@@ -63,7 +63,7 @@ class MachineConfig(PrintableConfig):
     """Configuration of machine setup"""
 
     seed: int = 42
-    """random seed initilization"""
+    """random seed initialization"""
     num_gpus: int = 1
     """total number of gpus available for train/eval"""
     num_machines: int = 1
@@ -88,6 +88,7 @@ class LocalWriterConfig(InstantiateConfig):
         writer.EventName.CURR_TEST_PSNR,
         writer.EventName.VIS_RAYS_PER_SEC,
         writer.EventName.TEST_RAYS_PER_SEC,
+        writer.EventName.ETA,
     )
     """specifies which stats will be logged/printed to terminal"""
     max_log_size: int = 10
@@ -112,7 +113,7 @@ class LoggingConfig(PrintableConfig):
     """number of steps between logging stats"""
     max_buffer_size: int = 20
     """maximum history size to keep for computing running averages of stats.
-     e.g. if 20, averages will be computed over past 20 occurances."""
+     e.g. if 20, averages will be computed over past 20 occurrences."""
     local_writer: LocalWriterConfig = LocalWriterConfig(enable=True)
     """if provided, will print stats locally. if None, will disable printing"""
     enable_profiler: bool = True
@@ -120,35 +121,6 @@ class LoggingConfig(PrintableConfig):
     profiler logs run times of functions and prints at end of training"""
 
 
-# Trainer related configs
-@dataclass
-class TrainerConfig(PrintableConfig):
-    """Configuration for training regimen"""
-
-    steps_per_save: int = 1000
-    """Number of steps between saves."""
-    steps_per_eval_batch: int = 500
-    """Number of steps between randomly sampled batches of rays."""
-    steps_per_eval_image: int = 500
-    """Number of steps between single eval images."""
-    steps_per_eval_all_images: int = 25000
-    """Number of steps between eval all images."""
-    max_num_iterations: int = 1000000
-    """Maximum number of iterations to run."""
-    mixed_precision: bool = False
-    """Whether or not to use mixed precision for training."""
-    relative_model_dir: Path = Path("nerfstudio_models/")
-    """Relative path to save all checkpoints."""
-    save_only_latest_checkpoint: bool = True
-    """Whether to only save the latest checkpoint or all checkpoints."""
-    # optional parameters if we want to resume training
-    load_dir: Optional[Path] = None
-    """Optionally specify a pre-trained model directory to load from."""
-    load_step: Optional[int] = None
-    """Optionally specify model step to load from; if none, will find most recent model in load_dir."""
-    load_config: Optional[Path] = None
-
-
 # Viewer related configs
 @dataclass
 class ViewerConfig(PrintableConfig):
