@@ -80,7 +80,7 @@ class Pipeline(nn.Module):
         device: location to place model and data
         test_mode:
             'train': loads train/eval datasets into memory
-            'test': loads train/test datset into memory
+            'test': loads train/test dataset into memory
             'inference': does not load any dataset into memory
         world_size: total number of machines available
         local_rank: rank of current machine
@@ -197,7 +197,7 @@ class VanillaPipeline(Pipeline):
         device: location to place model and data
         test_mode:
             'val': loads train/val datasets into memory
-            'test': loads train/test datset into memory
+            'test': loads train/test dataset into memory
             'inference': does not load any dataset into memory
         world_size: total number of machines available
         local_rank: rank of current machine
@@ -359,13 +359,7 @@ class VanillaPipeline(Pipeline):
             loaded_state: pre-trained model state dict
         """
         state = {key.replace("module.", ""): value for key, value in loaded_state.items()}
-        if self.test_mode == "inference":
-            state.pop("datamanager.train_camera_optimizer.pose_adjustment", None)
-            state.pop("datamanager.train_ray_generator.image_coords", None)
-            state.pop("datamanager.train_ray_generator.pose_optimizer.pose_adjustment", None)
-            state.pop("datamanager.eval_ray_generator.image_coords", None)
-            state.pop("datamanager.eval_ray_generator.pose_optimizer.pose_adjustment", None)
-        self.load_state_dict(state)  # type: ignore
+        self.load_state_dict(state, strict=False)
 
     def get_training_callbacks(
         self, training_callback_attributes: TrainingCallbackAttributes
